/***
  Socket Example - livetest.java

  This is an example of a client application that sends plot-data to
  XGraph via a socket from a Java program.

  It expects to see a socket number on the command-line.
  Otherwise it will use the default socket, 8000.

  Compile:	javac livetest.java

  Run:		xgraph -x_range 0 100 -y_range 0 1 -soc 8001 &
		java livetest 8001

   (It is also convenient to start the two programs in separate windows.)

 ***/

import java.io.IOException;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.Random;

public class livetest
{
 private PrintWriter out;

 public static void main(String[] args) 
 {
  int portNumber=8000, j, num=0;
  double X, Y;

  try
   {
    if (args.length == 1)
     portNumber = Integer.parseInt( args[0] );
    else
    if (args.length > 1)
     {
      System.out.println("Too many arguments on command-line.");
      System.exit( 1 );
     }

    System.out.println("Client waiting for socket" + portNumber );
    Socket soc = new Socket( "localhost", portNumber );
    PrintWriter out = new PrintWriter( soc.getOutputStream(), true );
    System.out.println("Client got socket, now sending data ...");

    for (X=0; X < 100; X++)
     {
      Y = Math.random();
      out.println( X + "  " + Y );		/* Send socket line. */
      num++;
     }  

    System.out.println("Client closing socket. Sent " + num + " lines.");
    soc.close();
   }
  catch (IOException e)
   {
      System.out.println("Client socket failed.");
      System.exit( 1 );
   }
 }

}
